@@ -1,6 +1,7 @@
 from .mms.channel import MMSChannel
 from .rcs.channel import RCSChannel
+from .sms.channel import SMSChannel
 from .web_rtc.channel import WebRtcChannel
 from .whatsapp.channel import WhatsAppChannel
 
-__all__ = ["WhatsAppChannel", "WebRtcChannel", "MMSChannel", "RCSChannel"]
+__all__ = ["WhatsAppChannel", "WebRtcChannel", "MMSChannel", "RCSChannel", "SMSChannel"]
